@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1676 2017-03-03 22:52:56Z mwall $
+# $Id: owfs.py 1700 2017-08-15 11:02:18Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -170,7 +170,7 @@ from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
 DRIVER_NAME = 'OWFS'
-DRIVER_VERSION = "0.20"
+DRIVER_VERSION = "0.21"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'owfs: %s' % msg)
@@ -448,6 +448,10 @@ class OWFSDriver(weewx.drivers.AbstractDevice):
             yield p
             time.sleep(self.polling_interval)
 
+    def closePort(self):
+        ow.finish()
+
+
 class OWFSService(weewx.engine.StdService):
     """Collect data from one-wire devices via owfs."""
 
@@ -487,6 +491,9 @@ class OWFSService(weewx.engine.StdService):
         else:
             self.bind(weewx.NEW_ARCHIVE_RECORD, self.handle_new_archive)
 
+    def shutDown(self):
+        ow.finish()
+
     def handle_new_loop(self, event):
         data = self.getData(event.packet)
         event.packet.update(data)
